Crate astroport_liquidity_helper

Crate astroport_liquidity_helper 

Astroport Liquidity Helper

This contract helps provide liquidity for Astroport pools and supports supplying liquidity with imbalanced assets. If the assets provided are not in the correct ratio, the contract will swap some of the assets so that the ratio of assets are the same as the pools reserves after the swap.

Re-exports

pub use crate::error::ContractError;

Modules

big_decimal
contract
error
math
Module containing implementations of calculations needed for swapping
msg
state